@@ -245,8 +245,7 @@ around new => sub {
     $orig->(@_, aoh => $data);
 };
 
-package ## no critic: Modules::RequireFilenameMatchesPackage
-    TableData::Business::ID::BPOM::NutritionLabelRef; # hide from PAUSE indexer
+package TableData::Business::ID::BPOM::NutritionLabelRef; # hide from PAUSE indexer
 
 use strict;
 
@@ -254,9 +253,9 @@ use Role::Tiny::With;
 with 'TableDataRole::Business::ID::BPOM::NutritionLabelRef';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-05-30'; # DATE
+our $DATE = '2024-06-13'; # DATE
 our $DIST = 'TableData-Business-ID-BPOM-NutritionLabelRef'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our %STATS = ("num_columns",4,"num_rows",228); # STATS
 
@@ -275,7 +274,7 @@ TableDataRole::Business::ID::BPOM::NutritionLabelRef - Nutrients
 
 =head1 VERSION
 
-This document describes version 0.003 of TableDataRole::Business::ID::BPOM::NutritionLabelRef (from Perl distribution TableData-Business-ID-BPOM-NutritionLabelRef), released on 2024-05-30.
+This document describes version 0.004 of TableDataRole::Business::ID::BPOM::NutritionLabelRef (from Perl distribution TableData-Business-ID-BPOM-NutritionLabelRef), released on 2024-06-13.
 
 =head1 SYNOPSIS
 
